
# Security Holding Package

This is a security holding package, a placeholder for a deleted package susceptible to hijacking.

(The package is completely empty)

For inquiries: [sec_reporting@service.jfrog.com](mailto:sec_reporting@service.jfrog.com)